@@ -70,6 +70,8 @@ enum generic
     Generic_BitRate_Encoded_String,
     Generic_FrameRate,
     Generic_FrameRate_String,
+    Generic_FrameRate_Num,
+    Generic_FrameRate_Den,
     Generic_FrameCount,
     Generic_Source_FrameCount,
     Generic_ColorSpace,
@@ -222,6 +224,8 @@ enum general
     General_CodecID_Hint,
     General_CodecID_Url,
     General_CodecID_Description,
+    General_CodecID_Version,
+    General_CodecID_Compatible,
     General_Interleaved,
     General_Codec,
     General_Codec_String,
@@ -257,6 +261,8 @@ enum general
     General_OverallBitRate_Maximum_String,
     General_FrameRate,
     General_FrameRate_String,
+    General_FrameRate_Num,
+    General_FrameRate_Den,
     General_FrameCount,
     General_Delay,
     General_Delay_String,
@@ -321,6 +327,7 @@ enum general
     General_Track_Sort,
     General_Track_Position,
     General_Track_Position_Total,
+    General_PackageName,
     General_Grouping,
     General_Chapter,
     General_SubTrack,
@@ -631,14 +638,18 @@ enum video
     Video_FrameRate_Mode_Original_String,
     Video_FrameRate,
     Video_FrameRate_String,
-    Video_FrameRate_Original,
-    Video_FrameRate_Original_String,
+    Video_FrameRate_Num,
+    Video_FrameRate_Den,
     Video_FrameRate_Minimum,
     Video_FrameRate_Minimum_String,
     Video_FrameRate_Nominal,
     Video_FrameRate_Nominal_String,
     Video_FrameRate_Maximum,
     Video_FrameRate_Maximum_String,
+    Video_FrameRate_Original,
+    Video_FrameRate_Original_String,
+    Video_FrameRate_Original_Num,
+    Video_FrameRate_Original_Den,
     Video_FrameCount,
     Video_Source_FrameCount,
     Video_Standard,
@@ -760,10 +771,14 @@ enum video
     Video_Language_String3,
     Video_Language_String4,
     Video_Language_More,
+    Video_Disabled,
+    Video_Disabled_String,
     Video_Default,
     Video_Default_String,
     Video_Forced,
     Video_Forced_String,
+    Video_AlternateGroup,
+    Video_AlternateGroup_String,
     Video_Encoded_Date,
     Video_Tagged_Date,
     Video_Encryption,
@@ -913,18 +928,23 @@ enum audio
     Audio_Matrix_ChannelPositions_String2,
     Audio_ChannelLayout,
     Audio_ChannelLayoutID,
+    Audio_SamplesPerFrame,
     Audio_SamplingRate,
     Audio_SamplingRate_String,
     Audio_SamplingCount,
     Audio_Source_SamplingCount,
     Audio_FrameRate,
     Audio_FrameRate_String,
+    Audio_FrameRate_Num,
+    Audio_FrameRate_Den,
     Audio_FrameCount,
     Audio_Source_FrameCount,
     Audio_Resolution,
     Audio_Resolution_String,
     Audio_BitDepth,
     Audio_BitDepth_String,
+    Audio_BitDepth_Detected,
+    Audio_BitDepth_Detected_String,
     Audio_BitDepth_Stored,
     Audio_BitDepth_Stored_String,
     Audio_Compression_Mode,
@@ -1029,10 +1049,14 @@ enum audio
     Audio_Language_String3,
     Audio_Language_String4,
     Audio_Language_More,
+    Audio_Disabled,
+    Audio_Disabled_String,
     Audio_Default,
     Audio_Default_String,
     Audio_Forced,
     Audio_Forced_String,
+    Audio_AlternateGroup,
+    Audio_AlternateGroup_String,
     Audio_Encoded_Date,
     Audio_Tagged_Date,
     Audio_Encryption,
@@ -1143,6 +1167,8 @@ enum text
     Text_FrameRate_Mode_String,
     Text_FrameRate,
     Text_FrameRate_String,
+    Text_FrameRate_Num,
+    Text_FrameRate_Den,
     Text_FrameRate_Minimum,
     Text_FrameRate_Minimum_String,
     Text_FrameRate_Nominal,
@@ -1152,6 +1178,7 @@ enum text
     Text_FrameRate_Original,
     Text_FrameRate_Original_String,
     Text_FrameCount,
+    Text_ElementCount,
     Text_Source_FrameCount,
     Text_ColorSpace,
     Text_ChromaSubsampling,
@@ -1251,10 +1278,14 @@ enum text
     Text_Language_String3,
     Text_Language_String4,
     Text_Language_More,
+    Text_Disabled,
+    Text_Disabled_String,
     Text_Default,
     Text_Default_String,
     Text_Forced,
     Text_Forced_String,
+    Text_AlternateGroup,
+    Text_AlternateGroup_String,
     Text_Summary,
     Text_Encoded_Date,
     Text_Tagged_Date,
@@ -1308,6 +1339,8 @@ enum other
     Other_Duration_End,
     Other_FrameRate,
     Other_FrameRate_String,
+    Other_FrameRate_Num,
+    Other_FrameRate_Den,
     Other_FrameCount,
     Other_TimeStamp_FirstFrame,
     Other_TimeStamp_FirstFrame_String,
@@ -1328,6 +1361,14 @@ enum other
     Other_Language_String3,
     Other_Language_String4,
     Other_Language_More,
+    Other_Disabled,
+    Other_Disabled_String,
+    Other_Default,
+    Other_Default_String,
+    Other_Forced,
+    Other_Forced_String,
+    Other_AlternateGroup,
+    Other_AlternateGroup_String,
 };
 
 //---------------------------------------------------------------------------
@@ -1422,10 +1463,14 @@ enum image
     Image_Language_String3,
     Image_Language_String4,
     Image_Language_More,
+    Image_Disabled,
+    Image_Disabled_String,
     Image_Default,
     Image_Default_String,
     Image_Forced,
     Image_Forced_String,
+    Image_AlternateGroup,
+    Image_AlternateGroup_String,
     Image_Summary,
     Image_Encoded_Date,
     Image_Tagged_Date,
@@ -1521,6 +1566,14 @@ enum menu
     Menu_TimeZones,
     Menu_LawRating,
     Menu_LawRating_Reason,
+    Menu_Disabled,
+    Menu_Disabled_String,
+    Menu_Default,
+    Menu_Default_String,
+    Menu_Forced,
+    Menu_Forced_String,
+    Menu_AlternateGroup,
+    Menu_AlternateGroup_String,
     Menu_Chapters_Pos_Begin,
     Menu_Chapters_Pos_End,
 };
